#!/bin/sh
# Only stop redis-server processes owned by the build user.
# A system redis may be present in the chroot but not killable by the
# unprivileged build user; never fail the build over that.
pkill -u "$(id -un)" redis-server || true
